![Test python package](https://github.com/mshumko/aurora-asi-lib/workflows/Test%20python%20package/badge.svg) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4746447.svg)](https://doi.org/10.5281/zenodo.4746446)

# aurora-asi-lib
Easily download, plot, animate, and analyze aurora all sky imager (ASI) data. Currently the two supported camera systems (arrays) are: 
* Red-line Emission Geospace Observatory (REGO)
* Time History of Events and Macroscale Interactions during Substorms (THEMIS).

[API Documentation](https://aurora-asi-lib.readthedocs.io/) | [Code on GitHub](https://github.com/mshumko/aurora-asi-lib) | [PyPI archive](https://pypi.org/project/aurora-asi-lib/)


Easily make ASI fisheye lens plots (example 1).

![Aurora plot from example 1.](https://github.com/mshumko/aurora-asi-lib/blob/main/docs/_static/example_1.png?raw=true)

Or project the image onto a map
![An ASI image projected onto a map](https://raw.githubusercontent.com/mshumko/aurora-asi-lib/main/docs/_static/donovan_2008_fig2b_map.png)

And make a keogram
![A keogram of a field line resonance](https://raw.githubusercontent.com/mshumko/aurora-asi-lib/mike_dev/docs/_static/keogram_gillies_2018_field_line_resonance.png)

And you can make movies
![Aurora movie from example 4.](https://github.com/mshumko/aurora-asi-lib/blob/main/docs/_static/20170915_023400_023557_themis_rank.gif?raw=true)

Feel free to contact me and request that I add other ASI arrays to `asilib`.